package bg.bas.dcl.CorpusTools;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.nio.channels.FileChannel;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;

public class CorpusSelector {
	
	public static void copyFile( File from, File to ) throws IOException {

	    if ( !to.exists() ) { to.createNewFile(); }

	    try {
	        FileChannel in = new FileInputStream( from ).getChannel();
	        FileChannel out = new FileOutputStream( to ).getChannel();

	        out.transferFrom( in, 0, in.size() );
	        
	        in.close();
	        out.close();
	    } catch (Exception e){
	    	System.err.println(e.getMessage());
	    }
	}

	/**
	 * @param args
	 */
	public static void main(String[] args) {
		// TODO Auto-generated method stub

		String path = args[0];
		String outpath = args[1];

	    File startingDirectory= new File(path);
	    List<File> files = null;
	    try{
	    	files = getFileListing(startingDirectory);
	    	System.out.println(files.size());
	    } catch(Exception e){
	    	System.err.println("GET listing error");
	    }

	    if (files == null) {
	    	System.err.println("Listing error "+path);
	    	System.exit(-1);
	    }


		for(File file : files ){
		      if (file.isFile()){
		    	  
		    	  String filename = file.getAbsolutePath();
		    	  
//		    	  String toname = filename.substring(path.length()+1);
//		    	  toname = toname.replaceAll("/", "-");
		    	  String toname = file.getName();
		    	  
		    	  try{
		    		 File to = new File(path + "/" + toname);
		    		 System.out.println(file.getAbsolutePath());
		    		 System.err.println(to.getAbsolutePath());
		    	  copyFile(file, to);
		    	  } catch (Exception e){
		  	    	System.err.println(e.getMessage());
		    		  
		    	  }
		    	  
		      }
		}
	}

	  /**
	   * Recursively walk a directory tree and return a List of all
	   * Files found; the List is sorted using File.compareTo().
	   *
	   * @param aStartingDir is a valid directory, which can be read.
	   */
	   static public List<File> getFileListing(
	     File aStartingDir
	   ) throws FileNotFoundException {
	     validateDirectory(aStartingDir);
	     List<File> result = getFileListingNoSort(aStartingDir);
	     Collections.sort(result);
	     return result;
	   }

	   // PRIVATE //
	   static private List<File> getFileListingNoSort(
	     File aStartingDir
	   ) throws FileNotFoundException {
	     List<File> result = new ArrayList<File>();
	     File[] filesAndDirs = aStartingDir.listFiles();
	     List<File> filesDirs = Arrays.asList(filesAndDirs);
	     for(File file : filesDirs) {
	       result.add(file); //always add, even if directory
	       if ( ! file.isFile() ) {
	         //must be a directory
	         //recursive call!
	         List<File> deeperList = getFileListingNoSort(file);
	         result.addAll(deeperList);
	       }
	     }
	     return result;
	   }

	   /**
	   * Directory is valid if it exists, does not represent a file, and can be read.
	   */
	   static private void validateDirectory (
	     File aDirectory
	   ) throws FileNotFoundException {
	     if (aDirectory == null) {
	       throw new IllegalArgumentException("Directory should not be null.");
	     }
	     if (!aDirectory.exists()) {
	       throw new FileNotFoundException("Directory does not exist: " + aDirectory);
	     }
	     if (!aDirectory.isDirectory()) {
	       throw new IllegalArgumentException("Is not a directory: " + aDirectory);
	     }
	     if (!aDirectory.canRead()) {
	       throw new IllegalArgumentException("Directory cannot be read: " + aDirectory);
	     }
	   }


}
